@@ -37,7 +37,7 @@ class RedisManager(PubSubManager):  # pragma: no cover
     name = 'redis'
 
     def __init__(self, url='redis://localhost:6379/0', channel='socketio',
-                 write_only=False):
+                 write_only=False, logger=None):
         if redis is None:
             raise RuntimeError('Redis package is not installed '
                                '(Run "pip install redis" in your '
@@ -45,7 +45,8 @@ class RedisManager(PubSubManager):  # pragma: no cover
         self.redis_url = url
         self._redis_connect()
         super(RedisManager, self).__init__(channel=channel,
-                                           write_only=write_only)
+                                           write_only=write_only,
+                                           logger=logger)
 
     def initialize(self):
         super(RedisManager, self).initialize()
